import { __awaiter, __decorate } from "tslib";
import { Connect } from '@genesislcap/foundation-comms';
import { observable, volatile, customElement, FASTElement } from '@microsoft/fast-element';
import * as Components from '../components';
import { FoundationInboxService } from '../services/foundation-inbox-service';
import { logger, getSeverityByMessageType } from '../utils';
import { ALL_SEVERITIES_TYPES } from './main.config';
import { MainStyles as styles } from './main.styles';
import { FoundationInboxTemplate as template } from './main.template';
/**
 * Foundation inbox component for displaying notifies list
 * Allow searching, filtering and deleting notifies
 * @deprecated - Use '\@genesislcap/pbc-notify-ui' instead.
 * 'https://www.npmjs.com/package/\@genesislcap/pbc-notify-ui'
 * @beta
 */
let FoundationInbox = class FoundationInbox extends FASTElement {
    constructor() {
        super(...arguments);
        this.notifies = [];
        this.notifiesFromFilter = [];
        this.ready = false;
        this.isLoading = false;
        this.searchText = '';
        this.severity = null;
        this.toastMenuItems = [
            {
                name: 'Remove',
                callback: (c) => {
                    c.event.target.$emit('remove-toast');
                },
                icon: {
                    name: 'trash',
                },
            },
        ];
    }
    searchTextChanged() {
        return __awaiter(this, void 0, void 0, function* () {
            this.getNotifiesFromFilter();
        });
    }
    severityChanged() {
        return __awaiter(this, void 0, void 0, function* () {
            this.getNotifiesFromFilter();
        });
    }
    get notifiesToDisplay() {
        return this.filtersToUse.types.length > 0 ? this.notifiesFromFilter : this.notifies;
    }
    get filtersToUse() {
        const types = [];
        const payload = {};
        if (this.searchText && this.searchText.length) {
            types.push('search');
            payload.search = this.searchText;
        }
        if (this.severity && ALL_SEVERITIES_TYPES.includes(this.severity)) {
            types.push('severity');
            payload.severity = getSeverityByMessageType(this.severity);
        }
        const result = {
            types,
            payload,
        };
        return result;
    }
    getNotifiesFromFilter() {
        return __awaiter(this, void 0, void 0, function* () {
            this.isLoading = true;
            this.notifiesFromFilter = yield this.foundationInboxService.filter(this.filtersToUse.types, this.filtersToUse.payload);
            this.isLoading = false;
        });
    }
    connectedCallback() {
        const _super = Object.create(null, {
            connectedCallback: { get: () => super.connectedCallback }
        });
        return __awaiter(this, void 0, void 0, function* () {
            _super.connectedCallback.call(this);
            logger.debug(`foundation-inbox is now connected to the DOM`);
            yield this.loadRemotes();
            this.isLoading = true;
            this.subscriptionHandler = ({ store }) => {
                this.notifies = (store === null || store === void 0 ? void 0 : store.items) || [];
                this.isLoading = false;
            };
            this.foundationInboxService.subscribe(this.subscriptionHandler);
        });
    }
    disconnectedCallback() {
        super.disconnectedCallback();
        this.foundationInboxService.unsubscribe(this.subscriptionHandler);
    }
    /**
     * Load remote components
     *
     * @remarks
     *
     * With regards to module federation
     *
     * @internal
     */
    loadRemotes() {
        return __awaiter(this, void 0, void 0, function* () {
            const remoteComponents = yield Components.loadRemotes();
            this.ready = true;
        });
    }
};
__decorate([
    Connect
], FoundationInbox.prototype, "connect", void 0);
__decorate([
    FoundationInboxService
], FoundationInbox.prototype, "foundationInboxService", void 0);
__decorate([
    observable
], FoundationInbox.prototype, "notifies", void 0);
__decorate([
    observable
], FoundationInbox.prototype, "notifiesFromFilter", void 0);
__decorate([
    observable
], FoundationInbox.prototype, "ready", void 0);
__decorate([
    observable
], FoundationInbox.prototype, "isLoading", void 0);
__decorate([
    observable
], FoundationInbox.prototype, "searchText", void 0);
__decorate([
    observable
], FoundationInbox.prototype, "severity", void 0);
__decorate([
    volatile
], FoundationInbox.prototype, "notifiesToDisplay", null);
__decorate([
    volatile
], FoundationInbox.prototype, "filtersToUse", null);
FoundationInbox = __decorate([
    customElement({
        name: 'foundation-inbox',
        template,
        styles,
    })
], FoundationInbox);
export { FoundationInbox };
