import { Connect } from '@genesislcap/foundation-comms';
import type { DropdownMenuItem } from '@genesislcap/foundation-ui';
import { ElementStyles } from '@microsoft/fast-element';
import { FASTElement } from '@microsoft/fast-element';
import { ViewTemplate } from '@microsoft/fast-element';

declare const ALL_SEVERITIES_TYPES: readonly ["default", "warning", "serious", "critical"];

declare type filterTypes = 'search' | 'severity';

/**
 * Foundation inbox component for displaying notifies list
 * Allow searching, filtering and deleting notifies
 * @deprecated - Use '\@genesislcap/pbc-notify-ui' instead.
 * 'https://www.npmjs.com/package/\@genesislcap/pbc-notify-ui'
 * @beta
 */
export declare class FoundationInbox extends FASTElement {
    connect: Connect;
    foundationInboxService: FoundationInboxService;
    notifies: Notify[];
    notifiesFromFilter: Notify[];
    ready: boolean;
    isLoading: boolean;
    searchText: string;
    private searchTextChanged;
    severity: SeverityType;
    private severityChanged;
    private subscriptionHandler;
    toastMenuItems: DropdownMenuItem[];
    get notifiesToDisplay(): Notify[];
    get filtersToUse(): {
        types: any[];
        payload: {
            search?: string;
            severity?: string;
        };
    };
    private getNotifiesFromFilter;
    connectedCallback(): Promise<void>;
    disconnectedCallback(): void;
    /**
     * Load remote components
     *
     * @remarks
     *
     * With regards to module federation
     *
     * @internal
     */
    loadRemotes(): Promise<void>;
}

declare interface FoundationInboxService {
    subscribe(callback: subscribeCallback): void;
    unsubscribe(callback: subscribeCallback): void;
    filter(filterType: filterTypes[], payload: {
        [filterType in filterTypes]?: string;
    }): Promise<Notify[]>;
}

declare interface FoundationInboxServiceStore {
    items: Notify[];
}

/**
 * @public
 */
export declare const FoundationInboxTemplate: ViewTemplate<FoundationInbox, any>;

/**
 * @public
 */
export declare const MainStyles: ElementStyles;

declare interface Notify {
    id: string;
    rowRef: string;
    type: SeverityType;
    title: string;
    content: string;
    date: string;
    actions?: NotifyAction[];
}

declare interface NotifyAction {
    text: string;
    fn(data?: any): void;
    cssClass: string;
}

declare type SeverityType = (typeof ALL_SEVERITIES_TYPES)[number];

declare type subscribeCallback = ({ store }: {
    store: FoundationInboxServiceStore;
}) => any;

export { }
